@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.26 2005/05/29 19:18:47 chpe Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.27 2006/01/22 15:58:59 crispin Exp $
  */
 
 #include "config.h"
@@ -303,7 +303,8 @@ update_actions (EphyWindow *window)
 
 	content_type = mozilla_get_content_type (embed);
 
-	if ((strcmp (content_type, "text/html") == 0)
+	if (content_type &&
+            (strcmp (content_type, "text/html") == 0)
 	    || (strcmp (content_type, "application/xhtml+xml") == 0)
 	    || (strcmp (content_type, "application/xml") == 0)
 	    || (strcmp (content_type, "text/xml") == 0))
