@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-rss-extension.c,v 1.10 2005/12/22 21:52:28 chpe Exp $
+ *  $Id: ephy-rss-extension.c,v 1.11 2006/01/18 15:42:02 jframeau Exp $
  */
 
 #include "config.h"
@@ -146,7 +146,7 @@ ephy_rss_feed_subscribe_cb (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	if (event == NULL) return;
 	
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 
 	
 
@@ -181,7 +181,7 @@ ephy_rss_ge_context_cb	(EphyEmbed *embed,
 		data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 		g_return_val_if_fail (data != NULL, FALSE);
 		
-		ephy_embed_event_get_property (event, "link", &value);
+		value = ephy_embed_event_get_property (event, "link");
 		address = g_value_get_string (value);
 		
 		active = rss_feedlist_contains (list, address);
